Stan Math Library: stan/math/fwd/scal/fun/acosh.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

acosh.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_ACOSH_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_ACOSH_HPP
3
4 #include <math.h>
5 #include <stan/math/fwd/core.hpp>
6 #include <stan/math/prim/scal/fun/constants.hpp>
7 #include <stan/math/prim/scal/fun/square.hpp>
8 #include <cmath>
9
10 namespace stan {
11 namespace math {
12
13 template <typename T>
14 inline fvar<T> acosh(const fvar<T>& x) {
15 using ::acosh;
16 using stan::math::square;
17 using std::sqrt;
18 using stan::math::NOT_A_NUMBER;
19 return fvar<T>(acosh(x.val_),
20 x.d_ / sqrt(square(x.val_) - 1));
21 }
22
23 }
24 }
25 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan::math::NOT_A_NUMBER
const double NOT_A_NUMBER
(Quiet) not-a-number value.
Definition: constants.hpp:56
stan
Definition: log_sum_exp.hpp:8
square.hpp
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::acosh
var acosh(const var &a)
The inverse hyperbolic cosine function for variables (C99).
Definition: acosh.hpp:68
constants.hpp
stan::math::acosh
fvar< T > acosh(const fvar< T > &x)
Definition: acosh.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.